@@ -233,7 +233,8 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
         elif edgeAttrDataProcess=="plus":
             htList=json.loads(csvDfItem.to_json(orient="records"))
             newHTList=[]
-            for htItem in tqdm.tqdm(range(0,len(htList),1024),desc="edge attr control-plus"):
+            for htI in tqdm.tqdm(range(0,len(htList),1024),desc="edge attr control-plus"):
+                htItem=htList[htI]
                 srcIdVal=htItem[srcIdAttr]
                 tgtIdVal=htItem[tgtIdAttr]
                 attrList=[keyItem for keyItem in htItem if keyItem not in [srcIdAttr,tgtIdAttr]]
